import { PrismaClient, Prisma } from '@prisma/client'; // Database
import { Response } from 'express';
import config from './config.js';
import log from './log.js';

// TODO: Add errorhandling with some sort of message.
const prisma = new PrismaClient({
	datasources: {
		db: {
			url: config.global.db_connection_string
		}
	}
});

// FIXME: any
export function handlePrismaError(errorObj: any, res: Response, source: string) {
	log.db.error(source, errorObj);
	if (errorObj instanceof Prisma.PrismaClientKnownRequestError) {
		switch (errorObj.code) {

			// P2002 -> "Unique constraint failed on the {constraint}"
			case 'P2002':
				res.status(409).json({ status: 'ERROR', errorcode: 'DB_ERROR', message: 'The object needs to be unique', meta: errorObj.meta });
				break;

			// P2003 -> "Foreign key constraint failed on the field: {field_name}"
			case 'P2003':
				res.status(404).json({ status: 'ERROR', errorcode: 'DB_ERROR', message: 'Relation object does not exist', meta: errorObj.meta });
				break;

			default:
				res.status(500).json({ status: 'ERROR', errorcode: 'DB_ERROR', message: 'An error occurred during the database operation' });
				break;
		}
	} else {
		res.status(500).json({ status: 'ERROR', errorcode: 'DB_ERROR', message: 'If you can read this something went terribly wrong!' });
	}
}

export default prisma;
