import express from 'express';
import path from 'node:path';
import __path from "../handlers/path.js";
import log from "../handlers/log.js";

// Middleware Imports
import { checkAuthentication } from '../middlewares/auth.mw.js'

// Route imports
import frontend_routes from './frontend/index.js';
import api_routes from './api/index.js';
//import auth_routes from './auth/index.js';

const Router = express.Router({ strict: false });

// static / libs routes
Router.use('/static', express.static(__path + '/static'));
Router.use('/libs/bulma', express.static(path.join(__path, 'node_modules', 'bulma', 'css'))); // http://192.168.221.10:3000/libs/bulma/bulma.css
Router.use('/libs/jquery', express.static(path.join(__path, 'node_modules', 'jquery', 'dist')));
Router.use('/libs/bootstrap-icons', express.static(path.join(__path, 'node_modules', 'bootstrap-icons')));

// Other routers
Router.use('/api', checkAuthentication, api_routes);
//Router.use('/auth', auth_routes);
Router.use('/', checkAuthentication, frontend_routes);


// Default route.
Router.all('*', function (req, res) {
	// TODO: Respond based on content-type (with req.is('application/json'))
	if (req.is('application/json')) {
		res.status(404).json({ errorcode: 'NOT_FOUND', error: 'Not Found!' });
	} else {
		res.status(404).render('errors/404', { url: req.originalUrl });
	}
});

export default Router;
